@@ -87,7 +87,7 @@ main (int argc, char **argv)
 
     onscreen = cogl_onscreen_new (data.ctx, 640, 480);
     cogl_onscreen_show (onscreen);
-    data.fb = COGL_FRAMEBUFFER (onscreen);
+    data.fb = onscreen;
 
     /* Prepare onscreen primitive */
     data.triangle = cogl_primitive_new_p2c4 (data.ctx,
@@ -95,11 +95,10 @@ main (int argc, char **argv)
                                              3, triangle_vertices);
     data.pipeline = cogl_pipeline_new (data.ctx);
 
-    data.offscreen_texture = COGL_TEXTURE (
+    data.offscreen_texture =
       cogl_texture_2d_new_with_size (data.ctx,
                                      OFFSCREEN_WIDTH,
-                                     OFFSCREEN_HEIGHT,
-                                     COGL_PIXEL_FORMAT_ANY));
+                                     OFFSCREEN_HEIGHT);
     data.offscreen = cogl_offscreen_new_with_texture (data.offscreen_texture);
 
     data.gles2_ctx = cogl_gles2_context_new (data.ctx, &error);
