@@ -30,6 +30,7 @@ typedef struct
   CoglBool              test_enable;
   CoglDepthTestFunction test_function;
   CoglBool              write_enable;
+  CoglBool              fb_write_enable;
   float                 range_near;
   float                 range_far;
 } TestDepthState;
@@ -67,6 +68,8 @@ draw_rectangle (TestState *state,
     {
       cogl_pipeline_set_color4ub (pipeline, Cr, Cg, Cb, Ca);
 
+      cogl_framebuffer_set_depth_write_enabled (test_fb,
+                                                rect_state->fb_write_enable);
       cogl_framebuffer_push_matrix (test_fb);
       cogl_framebuffer_translate (test_fb, 0, 0, rect_state->depth);
       cogl_framebuffer_draw_rectangle (test_fb,
@@ -140,6 +143,7 @@ paint (TestState *state)
       FALSE, /* depth test enable */
       COGL_DEPTH_TEST_FUNCTION_ALWAYS,
       TRUE, /* depth write enable */
+      TRUE, /* FB depth write enable */
       0, 1 /* depth range */
     };
     /* Furthest */
@@ -149,6 +153,7 @@ paint (TestState *state)
       TRUE, /* depth test enable */
       COGL_DEPTH_TEST_FUNCTION_ALWAYS,
       TRUE, /* depth write enable */
+      TRUE, /* FB depth write enable */
       0, 1 /* depth range */
     };
     /* In the middle */
@@ -158,6 +163,7 @@ paint (TestState *state)
       TRUE, /* depth test enable */
       COGL_DEPTH_TEST_FUNCTION_NEVER,
       TRUE, /* depth write enable */
+      TRUE, /* FB depth write enable */
       0, 1 /* depth range */
     };
 
@@ -190,6 +196,21 @@ paint (TestState *state)
                 &rect0_state, &rect1_state, &rect2_state,
                 FALSE, /* legacy mode */
                 0x0000ffff); /* expected */
+
+    rect1_state.write_enable = TRUE;
+    rect1_state.fb_write_enable = FALSE;
+    test_depth (state, 4, 0, /* position */
+                &rect0_state, &rect1_state, &rect2_state,
+                FALSE, /* legacy mode */
+                0x0000ffff); /* expected */
+
+    /* Re-enable FB depth writing to verify state flush */
+    rect1_state.write_enable = TRUE;
+    rect1_state.fb_write_enable = TRUE;
+    test_depth (state, 4, 0, /* position */
+                &rect0_state, &rect1_state, &rect2_state,
+                FALSE, /* legacy mode */
+                0x00ff00ff); /* expected */
   }
 
   /* Check that the depth buffer values can be mapped into different
@@ -203,6 +224,7 @@ paint (TestState *state)
       TRUE, /* depth test enable */
       COGL_DEPTH_TEST_FUNCTION_ALWAYS,
       TRUE, /* depth write enable */
+      TRUE, /* FB depth write enable */
       0.5, 1 /* depth range */
     };
     /* Furthest by depth, nearest by depth range */
@@ -212,6 +234,7 @@ paint (TestState *state)
       TRUE, /* depth test enable */
       COGL_DEPTH_TEST_FUNCTION_GREATER,
       TRUE, /* depth write enable */
+      TRUE, /* FB depth write enable */
       0, 0.5 /* depth range */
     };
 
@@ -232,6 +255,7 @@ paint (TestState *state)
       FALSE, /* depth test enable */
       COGL_DEPTH_TEST_FUNCTION_LESS,
       TRUE, /* depth write enable */
+      TRUE, /* FB depth write enable */
       0, 1 /* depth range */
     };
     /* Furthest */
@@ -241,6 +265,7 @@ paint (TestState *state)
       FALSE, /* depth test enable */
       COGL_DEPTH_TEST_FUNCTION_LESS,
       TRUE, /* depth write enable */
+      TRUE, /* FB depth write enable */
       0, 1 /* depth range */
     };
 
